[evolution-data-server/openismus-work-master: 105/118] Changes for Review: CursorExample fixed spelling mistakes



commit 25cad2a5c45b0d325e83cafd921c2b2d9b9d2d7f
Author: Tristan Van Berkom <tristanvb openismus com>
Date:   Sat Oct 5 23:47:11 2013 +0200

    Changes for Review: CursorExample fixed spelling mistakes

 tests/cursor-example/cursor-example.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/tests/cursor-example/cursor-example.c b/tests/cursor-example/cursor-example.c
index ad10966..efe01fa 100644
--- a/tests/cursor-example/cursor-example.c
+++ b/tests/cursor-example/cursor-example.c
@@ -536,11 +536,11 @@ cursor_example_update_current_index (CursorExample *example,
        gint                  index;
 
        /* Fetch the alphabetic index for this contact */
-       index = e_book_client_cursor_get_contact_alpabetic_index (priv->cursor, contact);
+       index = e_book_client_cursor_get_contact_alphabetic_index (priv->cursor, contact);
 
        /* Refresh the current alphabet index indicator.
         *
         * The index returned by e_book_client_cursor_get_contact_alpabetic_index() is
         * a valid position into the array returned by e_book_client_cursor_get_alphabet().
         */
        labels = e_book_client_cursor_get_alphabet (priv->cursor, NULL, NULL, NULL, NULL);
@@ -536,11 +536,11 @@ cursor_example_update_current_index (CursorExample *example,
        /* Refresh the current alphabet index indicator.
         *
-        * The index returned by e_book_client_cursor_get_contact_alpabetic_index() is
+        * The index returned by e_book_client_cursor_get_contact_alphabetic_index() is
         * a valid position into the array returned by e_book_client_cursor_get_alphabet().
         */


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]